/* -*- c-basic-offset: 4; tab-width: 8; indent-tabs-mode: t -*- */

/*
 * Copyright (c) 2001-2006 International Computer Science Institute
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software")
 * to deal in the Software without restriction, subject to the conditions
 * listed in the XORP LICENSE file. These conditions include: you must
 * preserve this copyright notice, and you cannot mention the copyright
 * holders in advertising related to the Software without their permission.
 * The Software is provided WITHOUT ANY WARRANTY, EXPRESS OR IMPLIED. This
 * notice is a summary of the XORP LICENSE file; the license in that file is
 * legally binding.
 */

/*
 * $XORP: xorp/libcomm/comm_module.h,v 1.6 2006/03/16 00:04:10 pavlin Exp $
 */

/*
 * Module definitions.
 */
#ifndef __LIBCOMM_COMM_MODULE_H__
#define __LIBCOMM_COMM_MODULE_H__

#ifndef	XORP_MODULE_NAME
#define XORP_MODULE_NAME	"LIBCOMM"
#endif
#ifndef XORP_MODULE_VERSION
#define XORP_MODULE_VERSION	"0.1"
#endif

#endif /* __LIBCOMM_COMM_MODULE_H__ */
